% rebase('base.tpl', title = "Tom's public emails")
<h1>Tom makes some emails public</h1>
<p>
  It's a lot easier for me to find things if they're
  on the public internet, and sometimes I don't even
  need to find things when they're there because other
  people find them for me. So please send email to
  <a href="mailto:Public (Thomas Levine) <public@thomaslevine.com>">public@thomaslevine.com</a>
  if it can be public. And keep using
  <a href="mailto:Thomas Levine <_@thomaslevine.com>">public@thomaslevine.com</a>
  for emails that you don't want to be public.
</p>
<h2>Why</h2>
<p>
  I think that making some emails public will make
  email easier for me and reduce my need for Facebook,
  Twitter, &amp;c.
</p>
<p>
  It also turns out to be a pretty convenient way to
  put any old file on the internet; just send it as an
  <a href="/!/id:20140915182359.GA28330@tlevine_vm/">attachment</a>.
</p>
<h2>Inconveniences</h2>
<p>
  Here are two things I don't like about the present software
  <a href="https://pypi.python.org/pypi/ejnug">ejnug</a>.
</p>
<p>
  First, email addresses are made public, and I think some people
  don't want their email addresses to be public. Email addresses are
  part of email messages, so I can't keep these secret while still making
  the emails public. If you want their email address not to get out,
  I suggest that you create separate email addresses, one that you tell
  everyone about and one that you only tell to your friends or whatever.
  If you are emailing with me, I'll use the public one when emailing from my
  public account and the private one when emailing from my private account.
</p>
<p>
  Second, if a bunch of people ran my system, we'd have a bunch of email
  websites, and it would be hard to sift through all of them. I think this
  is easier to deal with; we just need a separate thing that goes to all of
  these sites and displays all of the recent emails and perhaps figures out
  which are the most interesting. If I just expose an RSS feed of the recent
  messages, we can use ordinary RSS readers for this.
</p>
