.body { white-space: pre; }

html { background-color: black; color: white; }
article { margin-top: 0.5em; margin-bottom: 0.5em; }

html, article,
.threads > ul, .attachments > ol,
.heading p, h1, h2, h3, h4, h5
  { margin: 0; padding: 0; }
body { padding: 0; margin: 0 0 0.5em 0; }

nav > ul > li {
  float: left; list-style-type: none;
  margin-right: 1em;
}
nav > ul { height: 1.1em; margin-top: 0; padding: 0.5em; }
nav { background-color: grey; }

.threads li { list-style-type: none; }
.threads > ul ul, .attachments > ol { margin-left: 1em; padding-left: 0.5em; }
h1, h2, h3, h4, h5 { font-size: inherit; }
.attachments, .threads { color: grey; }
.body, .heading { color: white; }
.heading {
  margin-bottom: 1.5em;
  padding-bottom: 0.5em;
  border-bottom: solid 1px grey;
}
a, a:visited, a:hover { color: #fe57a1; } 
a, a:visited { text-decoration: none; }
a:hover { text-decoration: underline; }
